@@ -1,47 +1,32 @@
-package Data::Domain::Net;
-
+use 5.008;
 use strict;
 use warnings;
+
+package Data::Domain::Net;
+our $VERSION = '1.100840';
+# ABSTRACT: Data domain classes for IP addresses
 use Data::Domain::SemanticAdapter;
-
-
-our $VERSION = '0.02';
-
-
-use base 'Exporter';
-
-
+use Exporter qw(import);
 our %map = (
     IPv4 => 'Net::IPAddress::IPv4',
     IPv6 => 'Net::IPAddress::IPv6',
 );
-
-
-our %EXPORT_TAGS = (
-    util => [ keys %map ],
-);
-
-
+our %EXPORT_TAGS = (util => [ keys %map ],);
 our @EXPORT_OK = @{ $EXPORT_TAGS{all} = [ map { @$_ } values %EXPORT_TAGS ] };
-
-
 Data::Domain::SemanticAdapter::install_shortcuts(%map);
-
-
 1;
 
 
 __END__
-
-
+=pod
 
 =head1 NAME
 
 Data::Domain::Net - Data domain classes for IP addresses
 
-=head1 SYNOPSIS
+=head1 VERSION
 
-    Data::Domain::Net->new;
+version 1.100840
 
 =head1 DESCRIPTION
 
@@ -79,59 +64,39 @@ Arguments are passed on to the object's constructor.
 
 By using the C<:all> tag, you can import all of them.
 
-Data::Domain::Net inherits from L<Exporter>.
+=head1 INSTALLATION
 
-The superclass L<Exporter> defines these methods and functions:
-
-    as_heavy(), export(), export_fail(), export_ok_tags(), export_tags(),
-    export_to_level(), import(), require_version()
-
-=head1 METHODS
-
-=over 4
-
-
-
-=back
-
-=head1 TAGS
-
-If you talk about this module in blogs, on del.icio.us or anywhere else,
-please use the C<datadomainnet> tag.
-
-=head1 VERSION 
-                   
-This document describes version 0.02 of L<Data::Domain::Net>.
+See perlmodinstall for information and options on installing Perl modules.
 
 =head1 BUGS AND LIMITATIONS
 
 No bugs have been reported.
 
-Please report any bugs or feature requests to
-C<<bug-data-domain-net@rt.cpan.org>>, or through the web interface at
-L<http://rt.cpan.org>.
-
-=head1 INSTALLATION
-
-See perlmodinstall for information and options on installing Perl modules.
+Please report any bugs or feature requests through the web interface at
+L<http://rt.cpan.org/Public/Dist/Display.html?Name=Data-Domain-Net>.
 
 =head1 AVAILABILITY
 
 The latest version of this module is available from the Comprehensive Perl
-Archive Network (CPAN). Visit <http://www.perl.com/CPAN/> to find a CPAN
-site near you. Or see <http://www.perl.com/CPAN/authors/id/M/MA/MARCEL/>.
+Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
+site near you, or see
+L<http://search.cpan.org/dist/Data-Domain-Net/>.
+
+The development version lives at
+L<http://github.com/hanekomu/Data-Domain-Net/>.
+Instead of sending patches, please fork this project using the standard git
+and github infrastructure.
 
 =head1 AUTHOR
 
-Marcel GrE<uuml>nauer, C<< <marcel@cpan.org> >>
+  Marcel Gruenauer <marcel@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007 by Marcel GrE<uuml>nauer
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This software is copyright (c) 2007 by Marcel Gruenauer.
 
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
